@@ -1,3 +1,5 @@
+from past.builtins import xrange
+
 import time
 import MySQLdb
 
@@ -11,15 +13,15 @@ class CozyStore(object):
         self.kwargs = kwargs
         self._cursor = None
 
-    def get_cursor(self, use_cache=True):
+    def get_cursor(self, use_cache=True, lazy=True):
         ''' Get a cursor, return the same cursor if use_cache is True.
         '''
 
         if not use_cache:
-            return CozyCursor(*self.args, **self.kwargs)
+            return CozyCursor(lazy=lazy, *self.args, **self.kwargs)
 
         if self._cursor is None:
-            self._cursor = CozyCursor(*self.args, **self.kwargs)
+            self._cursor = CozyCursor(lazy=lazy, *self.args, **self.kwargs)
         return self._cursor
 
     def close(self):
@@ -31,15 +33,19 @@ class CozyStore(object):
 
 
 class CozyCursor(object):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, lazy=True, *args, **kwargs):
         ''' Accept the same arguments as MySQLdb.connect.
         '''
 
         self.args = args
         self.kwargs = kwargs
-        if 'init_command' not in self.args:
-            self.kwargs['init_command'] = 'set names utf8'
-        self._cursor = None
+        if 'init_command' not in self.kwargs:
+            self.kwargs['init_command'] = 'set names utf8mb4'
+        self._cursor = None if lazy else self._get_cursor()
+
+    def _get_cursor(self):
+        conn = MySQLdb.connect(*self.args, **self.kwargs)
+        return conn.cursor()
 
     @property
     def cursor(self):
@@ -47,8 +53,7 @@ class CozyCursor(object):
         '''
 
         if self._cursor is None:
-            conn = MySQLdb.connect(*self.args, **self.kwargs)
-            self._cursor = conn.cursor()
+            self._cursor = self._get_cursor()
         return self._cursor
 
     def __getattr__(self, name):
@@ -71,12 +76,12 @@ class CozyCursor(object):
 
         readonly_queries = {'select', 'show'}
         query_type = sql.strip().split(None, 1)[0].lower()
-        retry = max(int(retry), 0) if force_retry or query_type in \
-                readonly_queries else 0
+        retry = (max(int(retry), 0) if force_retry or query_type in
+                 readonly_queries else 0)
         for i in xrange(retry + 1):
             try:
                 return self.cursor.execute(sql, args)
-            except MySQLdb.OperationalError, oe:
+            except MySQLdb.OperationalError as oe:
                 # Only re-connect when error code is between 2000 and 3000
                 if 2000 <= oe.args[0] < 3000:
                     self.close()
